@@ -1,6 +1,6 @@
 /*****************************************************************************
  *                                                                           *
- *  Copyright (c) 2013-2016 Boris Pek <tehnick-8@mail.ru>                    *
+ *  Copyright (c) 2013-2017 Boris Pek <tehnick-8@yandex.ru>                  *
  *                                                                           *
  *  Permission is hereby granted, free of charge, to any person obtaining    *
  *  a copy of this software and associated documentation files (the          *
@@ -102,7 +102,7 @@ int main(int argc, char **argv)
     read_hosts();
     read_timestamps();
 
-    int counter = 0;
+    unsigned long counter = 0;
     while (FCGI_Accept() >= 0) {
         ++counter;
 
